==> patch-2.3.7.9.zip: app/Models/Support.php <==
<?php
namespace Models;

use Core\Model;
use Helpers\KLogger;

/**
 * Copyright 2014
 * ParaBlu Systems Private Limited
 * All Rights Reserved
 *
 * NOTICE:  All information contained herein is, and remains
 * the property of ParaBlu Systems Private Limited and its suppliers, if any.
 * The intellectual and technical concepts contained herein are proprietary
 * to ParaBlu Systems Private Limited and its suppliers and may be covered by
 * Indian, US and Foreign Patents, patents in process, and are protected by
 * trade secret or copyright law.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from ParaBlu Systems Private Limited.
 *
 * Class User
 * @package Models
 *
 * @author Prashanth Kumar B - prashanth.kumar@parablu.com
 * @version 2.0
 * @date June 10, 2015
 *
 */

class Support extends Model{

    /**
     * Constructing the parent
     */
    public function __construct(){
        parent::__construct();
        $this->log('Support Model was called', 'info');
    }

    /**
     * Below Method Blocks the user Profile
     *
     * loggedIn userName should be sent in header
     * @param $headers
     * @return array
     */
    public function getSupportLogs($headers){
        $url = $this->api->getUrl('supportLogs');
        KLogger::req($url,$headers,$data);
        $this->curl->setHeaders($headers);
        $this->curl->get($url);
        $result = array(
            'status' => ($this->curl->http_status_code == 201) ? 200 : $this->curl->http_status_code,
            'body' => $this->curl->response,
            'header' => $this->curl->response_headers
        );
        $this->log('Result'.json_encode($result), 'info');
        KLogger::res($this->curl->response,$this->curl->response_headers,$result['status']);
        return $result;
    }

    /**
     * Below Method Blocks the user Profile
     *
     * loggedIn userName should be sent in header
     * @param $headers
     * @return array
     */
    public function getLogDetails($headers, $logID){
        $url = $this->api->getUrl('logDetails', array('logID' => $logID));
        KLogger::req($url,$headers,$logID);
        $this->curl->setHeaders($headers);
        $this->curl->get($url);
        $result = array(
            'status' => ($this->curl->http_status_code == 201) ? 200 : $this->curl->http_status_code,
            'body' => $this->curl->response,
            'header' => $this->curl->response_headers
        );
        $this->log('Result'.json_encode($result), 'info');
        KLogger::res($this->curl->response,$this->curl->response_headers,$result['status']);
        return $result;
    }

    /**
     * Below Method Blocks the user Profile
     *
     * loggedIn userName should be sent in header
     * @param $path
     * @param $name
     * @return array
     */
    public function downloadLog($path, $name){
        if(!is_file($path) || CONNECTION_STATUS()!=0){
            return false;
        }
        HEADER("Cache-Control: private");
        HEADER("Pragma: public");
        HEADER("Expires: ".GMDATE("D, d M Y H:i:s", MKTIME(DATE("H")+2, DATE("i"), DATE("s"), DATE("m"), DATE("d"), DATE("Y")))." GMT");
        HEADER("Last-Modified: ".GMDATE("D, d M Y H:i:s")." GMT");
        HEADER("Content-Type: application/octet-stream");
        HEADER("Content-Length: ".(string)(FILESIZE($path)));
        HEADER("Content-Disposition: attachment; filename=".$name);
        HEADER("Content-Transfer-Encoding: binary");
        session_write_close();
        if($file = FOPEN($path, 'rb')) {
            while(!FEOF($file) && (CONNECTION_STATUS()==0)) {
                PRINT(FREAD($file, 1024*8));
                FLUSH();
            }
            FCLOSE($file);
        }
        return((CONNECTION_STATUS()==0) && !CONNECTION_ABORTED());
    }

}

==> patch-2.5.4.12.zip: app/Models/Support.php <==
<?php
namespace Models;

use Core\Model;
use Helpers\KLogger;

/**
 * Copyright 2014
 * ParaBlu Systems Private Limited
 * All Rights Reserved
 *
 * NOTICE:  All information contained herein is, and remains
 * the property of ParaBlu Systems Private Limited and its suppliers, if any.
 * The intellectual and technical concepts contained herein are proprietary
 * to ParaBlu Systems Private Limited and its suppliers and may be covered by
 * Indian, US and Foreign Patents, patents in process, and are protected by
 * trade secret or copyright law.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from ParaBlu Systems Private Limited.
 *
 * Class User
 * @package Models
 *
 * @author Prashanth Kumar B - prashanth.kumar@parablu.com
 * @version 2.0
 * @date June 10, 2015
 *
 */

class Support extends Model{

    /**
     * Constructing the parent
     */
    public function __construct(){
        parent::__construct();
        $this->log('Support Model was called', 'info');
    }

    /**
     * Below Method Blocks the user Profile
     *
     * loggedIn userName should be sent in header
     * @param $headers
     * @return array
     */
    public function getSupportLogs($headers,$pageNumber){
//        $url = $this->api->getUrl('supportLogs');
    $url = PROTOCOL.PARACLOUD_IP."/support/versions/2.5/clouds/".CLOUD_NAME."/logs/?pageNumber=".$pageNumber;
        Model::req($url,$headers,$data);
        $this->curl->setHeaders($headers);
        $this->curl->get($url);
        $result = array(
            'status' => ($this->curl->http_status_code == 201) ? 200 : $this->curl->http_status_code,
            'body' => $this->curl->response,
            'header' => $this->curl->response_headers
        );
        $this->log('Result'.json_encode($result), 'info');
        Model::res($this->curl->response,$this->curl->response_headers,$result['status']);
        return $result;
    }
    
    public function getSupportLogsNavigate($headers, $url){
//        $url = $this->api->getUrl('supportLogs');
        $url = PROTOCOL.PARACLOUD_IP.$url;
        Model::req($url,$headers,$data);
        $this->curl->setHeaders($headers);
        $this->curl->get($url);
        $result = array(
            'status' => ($this->curl->http_status_code == 201) ? 200 : $this->curl->http_status_code,
            'body' => $this->curl->response,
            'header' => $this->curl->response_headers
        );
        $this->log('Result'.json_encode($result), 'info');
        Model::res($this->curl->response,$this->curl->response_headers,$result['status']);
        return $result;
    }

    /**
     * Below Method Blocks the user Profile
     *
     * loggedIn userName should be sent in header
     * @param $headers
     * @return array
     */
    public function getLogDetails($headers, $logID){
        $url = $this->api->getUrl('logDetails', array('logID' => $logID));
        Model::req($url,$headers,$logID);
        $this->curl->setHeaders($headers);
        $this->curl->get($url);
        $result = array(
            'status' => ($this->curl->http_status_code == 201) ? 200 : $this->curl->http_status_code,
            'body' => $this->curl->response,
            'header' => $this->curl->response_headers
        );
        $this->log('Result'.json_encode($result), 'info');
        Model::res($this->curl->response,$this->curl->response_headers,$result['status']);
        return $result;
    }
    
    public function supportOverview($headers){
        $url = $this->api->getParacloudUrl('supportOverview');
        Model::req($url,$headers,$data);
        $this->curl->setHeaders($headers);
        $this->curl->get($url);
        $result = array(
            'status' => ($this->curl->http_status_code == 201) ? 200 : $this->curl->http_status_code,
            'body' => $this->curl->response,
            'header' => $this->curl->response_headers
        );
        $this->log('Result'.json_encode($result), 'info');
        Model::res($this->curl->response,$this->curl->response_headers,$result['status']);
        return $result;
    }

    /**
     * Below Method Blocks the user Profile
     *
     * loggedIn userName should be sent in header
     * @param $path
     * @param $name
     * @return array
     */
    public function downloadLog($path, $name){
        if(!is_file($path) || CONNECTION_STATUS()!=0){
            return false;
        }
        HEADER("Cache-Control: private");
        HEADER("Pragma: public");
        HEADER("Expires: ".GMDATE("D, d M Y H:i:s", MKTIME(DATE("H")+2, DATE("i"), DATE("s"), DATE("m"), DATE("d"), DATE("Y")))." GMT");
        HEADER("Last-Modified: ".GMDATE("D, d M Y H:i:s")." GMT");
        HEADER("Content-Type: application/octet-stream");
        HEADER("Content-Length: ".(string)(FILESIZE($path)));
        HEADER("Content-Disposition: attachment; filename=".$name);
        HEADER("Content-Transfer-Encoding: binary");
        session_write_close();
        if($file = FOPEN($path, 'rb')) {
            while(!FEOF($file) && (CONNECTION_STATUS()==0)) {
                PRINT(FREAD($file, 1024*8));
                FLUSH();
            }
            FCLOSE($file);
        }
        return((CONNECTION_STATUS()==0) && !CONNECTION_ABORTED());
    }

}
